import argparse
import bpy, sys

def set_screen_to(screen_name):
    context = bpy.context
    to_screen = bpy.data.screens.find(screen_name)
    if to_screen >= 0:
        # context.screen
        from_screen = bpy.data.screens.find(context.screen.name)
        delta = to_screen - from_screen
        sgn = abs(delta) / delta
        delta = abs(delta)
        for i in range(delta):
           bpy.ops.screen.screen_set('INVOKE_DEFAULT', delta=sgn)
        print("pm_to_blender: screen is now set to " + screen_name)
    else :
        print("can't find screen" + screen_name)
    context.screen.scene = bpy.data.scenes['polymake']

argv = sys.argv
if "--" not in argv:
    argv = []
else:
    argv = argv[argv.index("--") + 1:]

# set the prog name to match real usage
parser = argparse.ArgumentParser(
    # the normal -h flag is problematic, it shows the cycles render help. changed it to -i/--info
    add_help=False,              
    prefix_chars = '-+',             
    description = 'Import x3d file to blender.',
    prog = "blender -P "+__file__+" --",
)
parser.add_argument('-i', '--info', action='help', default=argparse.SUPPRESS,
                    help='Show this info message and exit.')
parser.add_argument("-t", "--transparency", action='store_true', 
                    help="Enables transparency for all imported objects.")
parser.add_argument("-d", "--deselect", action='store_true', 
                    help="Deselect everything") 
parser.add_argument("-f", "--file", dest="filepath", required=True,
                    help="X3D file to import")

args = parser.parse_args(argv)

ct = bpy.context
# import our created x3d file into a new scene
bpy.ops.scene.new(type='NEW')
ct.scene.name = 'polymake'
bpy.ops.import_scene.x3d(filepath=args.filepath)

# if you use blender as a viewer only, the following might be helpful
def enable_transparency():
    for obj in ct.scene.objects[:]:
        if obj.select_get() == True:
            obj.show_transparent = True                 # this enables transparency in a 3D VIEW (without "rendering")
            if obj.name == "Viewpoint":
                ct.scene.camera = obj

def deselect():
    for obj in ct.scene.objects[:]:
        obj.select_set(False)
if args.transparency: enable_transparency()
if args.deselect: deselect()



#!/usr/bin/python

import subprocess
import os
import re
import random
import sys
from math import log

grpFilePattern = re.compile(r'^G_(\d+)$')
methodPattern = re.compile(r'\s*--\s+(.*)$')
totalLog = {}
cmd = 'false'
number = '0'

def runPair(grp1, grp2):
    global totalLog
    fgrp1 = "G_%04d" % grp1
    fgrp2 = "G_%04d" % grp2
    cout = subprocess.Popen([cmd, fgrp1, fgrp2, number], stdout=subprocess.PIPE, bufsize=1024).stdout
    label = None
    for i in range(0,100):
        line = cout.readline()
        if not line:
            break
        m = methodPattern.match(line)
        if not m:
            if label:
                if not totalLog.has_key(label):
                    totalLog[label] = []
                totalLog[label].append(("%dc%d " % (grp1,grp2)) + line)
        else:
            label = m.group(1)

if len(sys.argv) < 4:
    print "no command or number given"
    print "usage:", sys.argv[0], "cmd", "numberOfRuns", "pairsFile"
    sys.exit(-1)
cmd = sys.argv[1]
number = sys.argv[2]
pairs = sys.argv[3]

plines = [l.strip() for l in open(pairs).readlines()]
pairs = [map(int, l.split(' ')) for l in plines]
for a, b in pairs:
    runPair(a, b)

for label in totalLog.keys():
    print label
    for l in totalLog[label]:
        print l,



#!/usr/bin/python
# -*- coding: utf-8 -*-

import subprocess
import os
import re
import random
import sys
from math import log

grpFilePattern = re.compile(r'^G_(\d+)$')
methodPattern = re.compile(r'\s*--\s+(.*)$')
totalLog = []
number = '0'

def runSet(degree, k, grp):
    global totalLog
    filename = "S1_%04d_%02d" % (degree, k)
    grpGenerators = [l.strip() for l in open(grp).readlines()]
    grpGenerators = [line.replace(',',')(').replace(' ',',') for line in grpGenerators[2:]]
    grpGenerators = ['(%s)' % line for line in grpGenerators];
    totalLog.append('G:=Group(%s);;' % (','.join(grpGenerators)))
    #totalLog.append('SC:=StabChainMutable(G);;')
    totalLog.append('r1:=Runtimes();;')

    sets = [l.strip() for l in open(filename).readlines()]
    sets = sets[1:int(number)+1]
    for s in sets:
        #totalLog.append('SCtemp:=CopyStabChain(SC);;')
        #totalLog.append('ChangeStabChain(SCtemp,[%s]);;' % (s.replace(' ',',')))
        totalLog.append('Stabilizer(G,[%s],OnSets);;' % (s.replace(' ',',')))
    
    totalLog.append('r2:=Runtimes();;')
    totalLog.append('Print("%04d %02d ", r2.user_time - r1.user_time, "\\n");;' % (degree, k))

if len(sys.argv) < 2:
    print "no number given"
    print "usage:", sys.argv[0], "numberOfRuns"
    sys.exit(-1)
number = sys.argv[1]

for root, dirs, files in os.walk("."):
    files.sort()
    for f in files:
        m = grpFilePattern.match(f)
        if not m:
            continue

        file = open(f)
        _ = file.readline()
        degree = int(file.readline())
        file.close()
        
        k = int(log(degree, 2))
        for l in range(k-3, k+2):
            runSet(degree, l, f)

for l in totalLog:
    print l



#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import re
import random
from math import log

def createSet(degree, k):
    filename = "S1_%04d_%02d" % (degree, k)
    if not os.path.exists(filename):
        print "creating", filename
        file = open(filename, "w")
        omega = range(1, degree+1)
        file.write(str(k) + "\n")
        for i in range(0, 10000):
            file.write(",".join([str(o) for o in random.sample(omega, k)]) + "\n")
        file.close()

grpFilePattern = re.compile(r'G_(\d+)')

for root, dirs, files in os.walk("."):
    for f in files:
        m = grpFilePattern.match(f)
        if not m:
            continue

        file = open(f)
        _ = file.readline()
        degree = int(file.readline())
        file.close()
        
        k = int(log(degree, 2))
        for l in range(k-3, k+2):
             createSet(degree, l)
        



#!/usr/bin/env python
import sys
n = int(sys.argv[1])

print "* %d-dim cube" % (n)
print "H-representation"
print "begin"
print " %d %d integer" % (2*n, n+1)
for i in range(0,n):
    print " ".join(['0'] + ['1' if (j % n == i) else '0' for j in range(0,n)])
for i in range(0,n):
    print " ".join(['1'] + ['-1' if (j % n == i) else '0' for j in range(0,n)])
print "end"



#!/usr/bin/python
# -*- coding: utf-8 -*-

import subprocess
import os
import re
import random
import sys
from math import log

grpFilePattern = re.compile(r'^G_(\d+)$')
methodPattern = re.compile(r'\s*--\s+(.*)$')
totalLog = {}
cmd = 'false'
number = '0'

def runSet(degree, k, grp):
    global totalLog
    filename = "S1_%04d_%02d" % (degree, k)
    print "running", cmd, 'at', filename
    cout = subprocess.Popen([cmd, grp, filename, number], stdout=subprocess.PIPE, bufsize=1024).stdout
    label = None
    for i in range(0,5000):
        line = cout.readline()
        if not line:
            break
        m = methodPattern.match(line)
        if not m:
            if label:
                if not totalLog.has_key(label):
                    totalLog[label] = []
                totalLog[label].append(line)
        else:
            label = m.group(1)

if len(sys.argv) < 3:
    print "no command or number given"
    print "usage:", sys.argv[0], "cmd", "numberOfRuns"
    sys.exit(-1)
cmd = sys.argv[1]
number = sys.argv[2]

for root, dirs, files in os.walk("."):
    files.sort()
    for f in files:
        m = grpFilePattern.match(f)
        if not m:
            continue

        file = open(f)
        _ = file.readline()
        degree = int(file.readline())
        file.close()
        
        k = int(log(degree, 2))
        for l in range(k-3, k+2):
            runSet(degree, l, f)

print "------"

k = totalLog.keys()
k.sort()
for label in k:
    print label
    for l in totalLog[label]:
        print l,
